@@ -9,11 +9,11 @@
 
 from pytonik.Request import Request
 from pytonik.Session import Session
-from pytonik.Editor import HTMLeditor
+from pytonik.Editor import Template
 from pytonik.Config import Config
 from pytonik.Log import Log
 from pytonik import Lang
-from pytonik import Version
+from pytonik.Version import *
 from pytonik.Core.env import env
 from pytonik.util.Variable import Variable
 from pytonik.Functions import url
@@ -53,8 +53,10 @@ header_response_page = {
 
 }
 
+data_c = {}
 
 class App(env, Config, Variable):
+
     def __getattr__(self, item):
         return item
 
@@ -81,6 +83,7 @@ class App(env, Config, Variable):
         self.languages = ""
         self.Driver = ""
         self.formData = None
+        self.datag = {}
 
     def getRouters(self):
 
@@ -95,8 +98,8 @@ class App(env, Config, Variable):
         return self.initial()
 
     def initial(self):
-        self.default("Framework", Version.AUTHOR)
-        self.default("X-Version", Version.VERSION_TEXT)
+        self.default("Framework", AUTHOR)
+        self.default("X-Version", VERSION_TEXT)
         self.getrouters = self.envrin('route')
         self.controllers = Controllers()
         self.methodprefix = self.controllers._getMethodPrefix()
@@ -113,7 +116,7 @@ class App(env, Config, Variable):
         controlUri = []
 
 
-        if Version.PYVERSION_MA >= 3:
+        if PYVERSION_MA >= 3:
             lrounters = self.getrouters.items()
         else:
             lrounters = self.getrouters.iteritems()
@@ -145,17 +148,19 @@ class App(env, Config, Variable):
 
         else:
 
-
             if str(self.controller[0]) == '?':
-
-                controllersClass = 'IndexController'
+                if self.controllers.default_controllers != "":
+                    controllersClass = str(self.controllers.default_controllers).capitalize() + 'Controller'
+                    
+                else:
+                    controllersClass = "IndexController"
             else:
 
-                controllersClass = str(self.controller[0].capitalize(
-                )) + str(self.controller[1:]) + 'Controller'
+                controllersClass = str(self.controller[0]).capitalize(
+                ) + str(self.controller[1:]) + 'Controller'
 
             controllersMethods = str(self.actions)
-
+        
         if controllersMethods != "":
             self.actions = controllersMethods
 
@@ -206,7 +211,7 @@ class App(env, Config, Variable):
 
         pageCode = "page{code}".format(code=code)
         if os.path.isdir(os.getcwd() + '/public'):
-            if self.out("SERVER_SOFTWARE") == Version.AUTHOR:
+            if self.out("SERVER_SOFTWARE") == AUTHOR:
                 re_url = ""
                 errorP = {}
                 if getErrorP != '':
@@ -374,7 +379,7 @@ class App(env, Config, Variable):
 
     def redirect(self, location='/', link=False, code="307"):
 
-        if self.out("SERVER_SOFTWARE") == Version.AUTHOR:
+        if self.out("SERVER_SOFTWARE") == AUTHOR:
 
             if link == True:
                 location_d = u.url().url(location)
@@ -396,7 +401,7 @@ class App(env, Config, Variable):
             print()
 
     def referer(self, location='/', link=False, code="307"):
-        if self.out("SERVER_SOFTWARE") == Version.AUTHOR:
+        if self.out("SERVER_SOFTWARE") == AUTHOR:
             if link == True:
                 location_d = u.url().url(location)
             else:
@@ -448,15 +453,20 @@ class App(env, Config, Variable):
             return strings
 
 
-    def XHreponse(self, dataString, type=""):
-        if self.out("SERVER_SOFTWARE") == Version.AUTHOR:
+    def XHreponse(self, dataString, ctype=""):
+        if self.out("SERVER_SOFTWARE") == AUTHOR:
             return dataString
         else:
-            self.header(type=type)
+            
+            for mime in MIME_TYPES:
+                if str(mime["ext"]).replace(".", "") == ctype or str(mime["ext"]).replace(".", "") == ctype:
+                    ctype = mime["type"]
+            self.header(type=ctype)
             print(dataString)
 
     def views(self, pathf="", datag={}, datal={}):
-
+        data_c.update(datag)
+        
         if pathf == "":
             pathf = self.getDefaultViewPath()
 
@@ -468,29 +478,31 @@ class App(env, Config, Variable):
             return self.errorP('404')
 
         else:
+            output = str('<!-- Pytonik -->\n') + self.read_html(host + DS + 'views' + DS, pathf, data_c) + str(
+                '\n<!-- Pytonik {} -->'.format(VERSION_TEXT))
             if os.path.isdir(os.getcwd() + '/public'):
                 # print(os.environ)
-                return self.read_html(host + DS + 'views' + DS, pathf, datag)
+                return output 
 
             else:
                 self.header()
-                print(self.read_html(host + DS + 'views' + DS, pathf, datag))
+                print(output)
+    
 
-    def read_html(self, template_dir, engine, context=[]):
 
+    def read_html(self, template_dir, engine, context={}):
+        data_c.update(context)
         html_file_path = os.path.join(template_dir, "%s.html" % engine)
-
         try:
             with open(html_file_path, encoding='utf-8') as html_file:
                 html = html_file.read()
-
-            return str('<!-- Pytonik -->\n') + HTMLeditor.Template(html).render(**context) + str(
-                '\n<!-- Pytonik {} -->'.format(Version.VERSION_TEXT))
+            
+            return Template.Template(html).render(**data_c)
 
         except Exception as err:
-
+            
             Log(template_dir + DS + engine + str('.html')).error(err)
-            return
+            return ""
 
     def getDefaultViewPath(self):
 
@@ -509,7 +521,7 @@ class App(env, Config, Variable):
         return host + DS + 'views' + DS + str(code) + ".html"
 
     def loadmodule(self):
-
+        
         path = [os.path.dirname(__file__) + str("/") +
                 str("Functions"), str(host) + str("/") + "model"]
         listpath = [path[0], path[1]]
@@ -536,7 +548,7 @@ class App(env, Config, Variable):
                     lclass0 = {name: name}
                     lclass.update(lclass0)
 
-        if Version.PYVERSION_MA <= 2:
+        if PYVERSION_MA <= 2:
             item = lclass.iteritems()
         else:
             item = lclass.items()
@@ -552,6 +564,7 @@ class App(env, Config, Variable):
             sys.path.append(host)
             import routes as route
             toroute, fromroute = "", ""
+            
             if len(route.route.getRouter()) > 0:
 
                 for i, redirect in enumerate(route.route.getCode()):
@@ -560,10 +573,14 @@ class App(env, Config, Variable):
                     if len(route.route.getDespatch()) > 0:
                         fromroute = route.route.getDespatch()[i]
                     if fromroute == self.controller:
+                        
                         self.redirect(location=toroute,
                                       link=True, code=redirect)
-
+                
                 for i, route_c in enumerate(route.route.getRouter()):
+                    
+                    
+                    
                     uri = self.uri
                     while("" in uri):
                         try:
@@ -583,10 +600,11 @@ class App(env, Config, Variable):
 
                     else:
                         luri = str(uri)
-
-
+                    
                     if luri == route_c:
-
+                        routes_l = route_c
+                
+                    
                         if len(route.route.getController()) > 0:
                             self.controller = route.route.getController()[i]
 
@@ -604,3 +622,4 @@ class App(env, Config, Variable):
                                         self.actions) + " Requires " + self.method)
 
                                     return self.errorP('400')
+                        
