@@ -321,7 +321,7 @@ class Table:
         return self
 
     def delete(self):
-        self.table_delete = "DELETE FROM {table} {where}".format(table=self.table, where=self.table_where)
+        self.table_delete = "DELETE FROM {table} {where}".format(table=self.table, where=str(" WHERE") + str(" AND".join(self.table_where)))
         t_result = self.DB.query(self.table_delete)
         return t_result.save() if t_result.Exception == "" else t_result.Exception
 
@@ -630,13 +630,14 @@ class Table:
                         lt = l.items()
                     for k, v in lt:
                         if k not in column:
-                            column.append('{k}="{v}"'.format(k=k, v=v))
+                            column.append("{k}='{v}'".format(k=k, v=v))
 
                 lcolumn = ' , '.join(column)
-
-                table_update = "UPDATE {table} SET {column} {where}".format(table=str(self.table),
-                                                                            column=lcolumn, where=self.table_where)
+                
+                table_update ="UPDATE {table} SET {column} {where}".format(table=str(self.table),  column=lcolumn, where=str(" WHERE") + str(" AND".join(self.table_where)) if len(self.table_where) > 0 else '')
+                
                 t_result = self.DB.query(table_update)
+                
                 return t_result.save() if t_result.Exception == "" else t_result.Exception
             else:
                 return "Empty Data"
